Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2389)

Unified Diff: ash/common/shelf/app_list_button.h

Issue 2679133003: [ash-md] Wired in the Shelf color to be derived from the Wallpaper. (Closed)
Patch Set: Addressed nits. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/common/ash_switches.cc ('k') | ash/common/shelf/app_list_button.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/common/shelf/app_list_button.h
diff --git a/ash/common/shelf/app_list_button.h b/ash/common/shelf/app_list_button.h
index 79460cc6f11279db9bd431d9eb1dda5ea574cf75..e6d55bf182ebe03d9b56d1c4a6e2e144c14aa9d6 100644
--- a/ash/common/shelf/app_list_button.h
+++ b/ash/common/shelf/app_list_button.h
@@ -7,6 +7,7 @@
#include "ash/ash_export.h"
#include "base/macros.h"
+#include "third_party/skia/include/core/SkColor.h"
#include "ui/views/controls/button/image_button.h"
namespace ash {
@@ -29,8 +30,8 @@ class ASH_EXPORT AppListButton : public views::ImageButton {
bool draw_background_as_active() const { return draw_background_as_active_; }
- // Sets alpha value of the background and schedules a paint.
- void SetBackgroundAlpha(int alpha);
+ // Updates background and schedules a paint.
+ void UpdateShelfItemBackground(SkColor color);
protected:
// views::ImageButton overrides:
@@ -73,8 +74,8 @@ class ASH_EXPORT AppListButton : public views::ImageButton {
// the application list.
bool draw_background_as_active_;
- // Alpha value used to paint the background.
- int background_alpha_;
+ // Color used to paint the background.
+ SkColor background_color_;
InkDropButtonListener* listener_;
ShelfView* shelf_view_;
« no previous file with comments | « ash/common/ash_switches.cc ('k') | ash/common/shelf/app_list_button.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698